@@ -1,5 +1,5 @@
 /* Character set conversion with error handling and autodetection.
-   Copyright (C) 2002, 2005, 2007-2021 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2005, 2007-2022 Free Software Foundation, Inc.
    Written by Bruno Haible.
 
    This file is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 #define _STRICONVEHA_H
 
 #include <stdbool.h>
-#include <stddef.h>
+#include <stdlib.h>
 
 #include "iconveh.h"
 
@@ -69,7 +69,8 @@ extern char *
        str_iconveha (const char *src,
                      const char *from_codeset, const char *to_codeset,
                      bool transliterate,
-                     enum iconv_ilseq_handler handler);
+                     enum iconv_ilseq_handler handler)
+       _GL_ATTRIBUTE_MALLOC _GL_ATTRIBUTE_DEALLOC_FREE;
 
 
 /* In the above, FROM_CODESET can also be one of the following values:
